==> SCFiler2-0.13.zip: SCFiler2/SCFiler2/FileView.Designer.cs <==
﻿namespace SCFiler2 {
	partial class FileView {
		/// <summary> 
		/// 必要なデザイナ変数です。
		/// </summary>
		private System.ComponentModel.IContainer components = null;

		/// <summary> 
		/// 使用中のリソースをすべてクリーンアップします。
		/// </summary>
		/// <param name="disposing">マネージ リソースが破棄される場合 true、破棄されない場合は false です。</param>
		protected override void Dispose(bool disposing) {
			if (disposing && (components != null)) {
				components.Dispose();
			}
			base.Dispose(disposing);
		}

		#region コンポーネント デザイナで生成されたコード

		/// <summary> 
		/// デザイナ サポートに必要なメソッドです。このメソッドの内容を 
		/// コード エディタで変更しないでください。
		/// </summary>
		private void InitializeComponent() {
			this.folder_path_panel = new System.Windows.Forms.Panel();
			this.current_path_label = new System.Windows.Forms.Label();
			this.drive_info_panel = new System.Windows.Forms.Panel();
			this.list_view = new System.Windows.Forms.ListView();
			this.drive_info_label = new System.Windows.Forms.Label();
			this.folder_info_label = new System.Windows.Forms.Label();
			this.folder_path_panel.SuspendLayout();
			this.drive_info_panel.SuspendLayout();
			this.SuspendLayout();
			// 
			// folder_path_panel
			// 
			this.folder_path_panel.Controls.Add(this.current_path_label);
			this.folder_path_panel.Dock = System.Windows.Forms.DockStyle.Top;
			this.folder_path_panel.Location = new System.Drawing.Point(0, 0);
			this.folder_path_panel.Name = "folder_path_panel";
			this.folder_path_panel.Size = new System.Drawing.Size(177, 16);
			this.folder_path_panel.TabIndex = 0;
			// 
			// current_path_label
			// 
			this.current_path_label.AutoSize = true;
			this.current_path_label.ForeColor = System.Drawing.SystemColors.WindowText;
			this.current_path_label.Location = new System.Drawing.Point(3, 3);
			this.current_path_label.Name = "current_path_label";
			this.current_path_label.Size = new System.Drawing.Size(35, 12);
			this.current_path_label.TabIndex = 0;
			this.current_path_label.Text = "label1";
			// 
			// drive_info_panel
			// 
			this.drive_info_panel.BorderStyle = System.Windows.Forms.BorderStyle.FixedSingle;
			this.drive_info_panel.Controls.Add(this.folder_info_label);
			this.drive_info_panel.Controls.Add(this.drive_info_label);
			this.drive_info_panel.Dock = System.Windows.Forms.DockStyle.Bottom;
			this.drive_info_panel.ForeColor = System.Drawing.SystemColors.Desktop;
			this.drive_info_panel.Location = new System.Drawing.Point(0, 146);
			this.drive_info_panel.Name = "drive_info_panel";
			this.drive_info_panel.Size = new System.Drawing.Size(177, 32);
			this.drive_info_panel.TabIndex = 1;
			// 
			// list_view
			// 
			this.list_view.AllowDrop = true;
			this.list_view.Dock = System.Windows.Forms.DockStyle.Fill;
			this.list_view.FullRowSelect = true;
			this.list_view.Location = new System.Drawing.Point(0, 16);
			this.list_view.Name = "list_view";
			this.list_view.Size = new System.Drawing.Size(177, 130);
			this.list_view.TabIndex = 2;
			this.list_view.UseCompatibleStateImageBehavior = false;
			this.list_view.View = System.Windows.Forms.View.Details;
			this.list_view.DragEnter += new System.Windows.Forms.DragEventHandler(this.list_view_DragEnter);
			this.list_view.DragDrop += new System.Windows.Forms.DragEventHandler(this.list_view_DragDrop);
			this.list_view.DoubleClick += new System.EventHandler(this.list_view_DoubleClick);
			this.list_view.MouseUp += new System.Windows.Forms.MouseEventHandler(this.list_view_MouseUp);
			this.list_view.KeyDown += new System.Windows.Forms.KeyEventHandler(this.file_list_view_KeyDown);
			this.list_view.KeyPress += new System.Windows.Forms.KeyPressEventHandler(this.list_view_KeyPress);
			this.list_view.ItemDrag += new System.Windows.Forms.ItemDragEventHandler(this.list_view_ItemDrag);
			// 
			// drive_info_label
			// 
			this.drive_info_label.AutoSize = true;
			this.drive_info_label.Location = new System.Drawing.Point(2, 3);
			this.drive_info_label.Name = "drive_info_label";
			this.drive_info_label.Size = new System.Drawing.Size(35, 12);
			this.drive_info_label.TabIndex = 0;
			this.drive_info_label.Text = "label1";
			// 
			// folder_info_label
			// 
			this.folder_info_label.AutoSize = true;
			this.folder_info_label.Location = new System.Drawing.Point(2, 16);
			this.folder_info_label.Name = "folder_info_label";
			this.folder_info_label.Size = new System.Drawing.Size(35, 12);
			this.folder_info_label.TabIndex = 1;
			this.folder_info_label.Text = "label2";
			// 
			// FileView
			// 
			this.AutoScaleDimensions = new System.Drawing.SizeF(6F, 12F);
			this.AutoScaleMode = System.Windows.Forms.AutoScaleMode.Font;
			this.Controls.Add(this.list_view);
			this.Controls.Add(this.drive_info_panel);
			this.Controls.Add(this.folder_path_panel);
			this.Name = "FileView";
			this.Size = new System.Drawing.Size(177, 178);
			this.Enter += new System.EventHandler(this.FileView_Enter);
			this.Leave += new System.EventHandler(this.FileView_Leave);
			this.folder_path_panel.ResumeLayout(false);
			this.folder_path_panel.PerformLayout();
			this.drive_info_panel.ResumeLayout(false);
			this.drive_info_panel.PerformLayout();
			this.ResumeLayout(false);

		}

		#endregion

		private System.Windows.Forms.Panel folder_path_panel;
		private System.Windows.Forms.Panel drive_info_panel;
		private System.Windows.Forms.ListView list_view;
		private System.Windows.Forms.Label current_path_label;
		private System.Windows.Forms.Label folder_info_label;
		private System.Windows.Forms.Label drive_info_label;
	}
}

==> SCFiler2-0.14.zip: SCFiler2/SCFiler2/FileView.Designer.cs <==
﻿namespace SCFiler2 {
	partial class FileView {
		/// <summary> 
		/// 必要なデザイナ変数です。
		/// </summary>
		private System.ComponentModel.IContainer components = null;

		/// <summary> 
		/// 使用中のリソースをすべてクリーンアップします。
		/// </summary>
		/// <param name="disposing">マネージ リソースが破棄される場合 true、破棄されない場合は false です。</param>
		protected override void Dispose(bool disposing) {
			if (disposing && (components != null)) {
				components.Dispose();
			}
			base.Dispose(disposing);
		}

		#region コンポーネント デザイナで生成されたコード

		/// <summary> 
		/// デザイナ サポートに必要なメソッドです。このメソッドの内容を 
		/// コード エディタで変更しないでください。
		/// </summary>
		private void InitializeComponent() {
			this.drive_info_panel = new System.Windows.Forms.Panel();
			this.folder_info_label = new System.Windows.Forms.Label();
			this.drive_info_label = new System.Windows.Forms.Label();
			this.list_view = new System.Windows.Forms.ListView();
			this.current_path_text = new System.Windows.Forms.TextBox();
			this.drive_info_panel.SuspendLayout();
			this.SuspendLayout();
			// 
			// drive_info_panel
			// 
			this.drive_info_panel.BorderStyle = System.Windows.Forms.BorderStyle.FixedSingle;
			this.drive_info_panel.Controls.Add(this.folder_info_label);
			this.drive_info_panel.Controls.Add(this.drive_info_label);
			this.drive_info_panel.Dock = System.Windows.Forms.DockStyle.Bottom;
			this.drive_info_panel.ForeColor = System.Drawing.SystemColors.Desktop;
			this.drive_info_panel.Location = new System.Drawing.Point(0, 146);
			this.drive_info_panel.Name = "drive_info_panel";
			this.drive_info_panel.Size = new System.Drawing.Size(177, 32);
			this.drive_info_panel.TabIndex = 1;
			// 
			// folder_info_label
			// 
			this.folder_info_label.AutoSize = true;
			this.folder_info_label.Location = new System.Drawing.Point(2, 16);
			this.folder_info_label.Name = "folder_info_label";
			this.folder_info_label.Size = new System.Drawing.Size(35, 12);
			this.folder_info_label.TabIndex = 1;
			this.folder_info_label.Text = "label2";
			// 
			// drive_info_label
			// 
			this.drive_info_label.AutoSize = true;
			this.drive_info_label.Location = new System.Drawing.Point(2, 3);
			this.drive_info_label.Name = "drive_info_label";
			this.drive_info_label.Size = new System.Drawing.Size(35, 12);
			this.drive_info_label.TabIndex = 0;
			this.drive_info_label.Text = "label1";
			// 
			// list_view
			// 
			this.list_view.AllowDrop = true;
			this.list_view.Dock = System.Windows.Forms.DockStyle.Fill;
			this.list_view.FullRowSelect = true;
			this.list_view.Location = new System.Drawing.Point(0, 19);
			this.list_view.Name = "list_view";
			this.list_view.Size = new System.Drawing.Size(177, 127);
			this.list_view.TabIndex = 2;
			this.list_view.UseCompatibleStateImageBehavior = false;
			this.list_view.View = System.Windows.Forms.View.Details;
			this.list_view.DragEnter += new System.Windows.Forms.DragEventHandler(this.list_view_DragEnter);
			this.list_view.DragDrop += new System.Windows.Forms.DragEventHandler(this.list_view_DragDrop);
			this.list_view.DoubleClick += new System.EventHandler(this.list_view_DoubleClick);
			this.list_view.MouseUp += new System.Windows.Forms.MouseEventHandler(this.list_view_MouseUp);
			this.list_view.KeyDown += new System.Windows.Forms.KeyEventHandler(this.file_list_view_KeyDown);
			this.list_view.KeyPress += new System.Windows.Forms.KeyPressEventHandler(this.list_view_KeyPress);
			this.list_view.ItemDrag += new System.Windows.Forms.ItemDragEventHandler(this.list_view_ItemDrag);
			// 
			// current_path_text
			// 
			this.current_path_text.Dock = System.Windows.Forms.DockStyle.Top;
			this.current_path_text.Location = new System.Drawing.Point(0, 0);
			this.current_path_text.Name = "current_path_text";
			this.current_path_text.Size = new System.Drawing.Size(177, 19);
			this.current_path_text.TabIndex = 3;
			this.current_path_text.TabStop = false;
			this.current_path_text.MouseMove += new System.Windows.Forms.MouseEventHandler(this.current_path_text_MouseMove);
			this.current_path_text.MouseClick += new System.Windows.Forms.MouseEventHandler(this.current_path_text_MouseClick);
			this.current_path_text.MouseUp += new System.Windows.Forms.MouseEventHandler(this.current_path_text_MouseUp);
			this.current_path_text.KeyDown += new System.Windows.Forms.KeyEventHandler(this.current_path_text_KeyDown);
			// 
			// FileView
			// 
			this.AutoScaleDimensions = new System.Drawing.SizeF(6F, 12F);
			this.AutoScaleMode = System.Windows.Forms.AutoScaleMode.Font;
			this.Controls.Add(this.list_view);
			this.Controls.Add(this.drive_info_panel);
			this.Controls.Add(this.current_path_text);
			this.Name = "FileView";
			this.Size = new System.Drawing.Size(177, 178);
			this.Enter += new System.EventHandler(this.FileView_Enter);
			this.Leave += new System.EventHandler(this.FileView_Leave);
			this.drive_info_panel.ResumeLayout(false);
			this.drive_info_panel.PerformLayout();
			this.ResumeLayout(false);
			this.PerformLayout();

		}

		#endregion

		private System.Windows.Forms.Panel drive_info_panel;
		private System.Windows.Forms.ListView list_view;
		private System.Windows.Forms.Label folder_info_label;
		private System.Windows.Forms.Label drive_info_label;
		private System.Windows.Forms.TextBox current_path_text;
	}
}
